@@ -48,19 +48,19 @@ SKGDeletePlugin::SKGDeletePlugin(QWidget* iWidget, QObject* iParent, const QVari
     SKGInterfacePlugin(iParent), m_deleteAction(NULL), m_currentDocument(NULL)
 {
     Q_UNUSED(iWidget);
-    SKGTRACEIN(10, "SKGDeletePlugin::SKGDeletePlugin");
+    SKGTRACEINFUNC(10);
 }
 
 SKGDeletePlugin::~SKGDeletePlugin()
 {
-    SKGTRACEIN(10, "SKGDeletePlugin::~SKGDeletePlugin");
+    SKGTRACEINFUNC(10);
     m_currentDocument = NULL;
     m_deleteAction = NULL;
 }
 
 bool SKGDeletePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
-    SKGTRACEIN(10, "SKGDeletePlugin::setupActions");
+    SKGTRACEINFUNC(10);
     Q_UNUSED(iArgument);
 
     m_currentDocument = iDocument;
@@ -78,9 +78,11 @@ bool SKGDeletePlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
 
 void SKGDeletePlugin::refresh()
 {
-    SKGTRACEIN(10, "SKGDeletePlugin::refresh");
+    SKGTRACEINFUNC(10);
 
-    if (m_deleteAction && SKGMainPanel::getMainPanel()) m_deleteAction->setEnabled(SKGMainPanel::getMainPanel()->getSelectedObjects().count() > 0);
+    if (m_deleteAction && SKGMainPanel::getMainPanel()) {
+        m_deleteAction->setEnabled(SKGMainPanel::getMainPanel()->getSelectedObjects().count() > 0);
+    }
 }
 
 QString SKGDeletePlugin::title() const
@@ -96,7 +98,7 @@ int SKGDeletePlugin::getOrder() const
 void SKGDeletePlugin::onDelete()
 {
     SKGError err;
-    SKGTRACEINRC(10, "SKGDeletePlugin::onDelete", err);
+    SKGTRACEINFUNCRC(10, err);
     if (SKGMainPanel::getMainPanel() && m_currentDocument) {
         {
             SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
@@ -112,7 +114,9 @@ void SKGDeletePlugin::onDelete()
                                                         KStandardGuiItem::yes(), KStandardGuiItem::no(),
                                                         "forcedelete");
                     QApplication::restoreOverrideCursor();
-                    if (rc == KMessageBox::Yes) err = selection[i].remove(true, true);
+                    if (rc == KMessageBox::Yes) {
+                        err = selection[i].remove(true, true);
+                    }
                 }
                 IFOKDO(err, m_currentDocument->stepForward(i + 1))
             }
