@@ -242,9 +242,21 @@ SKGAdviceList SKGBankPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(3);
             ad.setShortMessage(i18nc("A account is closed but the amount is not equal to 0", "Closed account '%1' still has money", account));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "This is may be not normal"));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Action to reopen the account", "Reopen '%1'", account));
-            autoCorrections.push_back(i18nc("Action to create a fake operation to set the amount of the account to 0", "Create fake operation"));
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Action to reopen the account", "Reopen '%1'", account);
+	      a.IconName="edit_undo";
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Action to create a fake operation to set the amount of the account to 0", "Create fake operation");
+	      a.IconName="edit-delete";
+	      a.IsRecommended=true;
+	      autoCorrections.push_back(a);
+	    }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
