@@ -331,8 +331,13 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(5);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Many unused categories"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "You can improve performances by removing categories that have no operations."));
-            QStringList autoCorrections;
-            autoCorrections.push_back("skg://clean_delete_unused_categories");
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title="skg://clean_delete_unused_categories";
+	      a.IsRecommended=true;
+	      autoCorrections.push_back(a);
+	    }	
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -354,8 +359,14 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(7);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Important variation for '%1'", listCategories.at(i)));
             ad.setLongMessage(listVariations.at(i));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Open sub operations with category containing '%1'", listCategories.at(i)));
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Open sub operations with category containing '%1'", listCategories.at(i));
+	      a.IconName="skg_open";
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }	
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -371,8 +382,13 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(3);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Some categories seem to be identical"));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "Some categories seem to be identical but with different syntax. They could be merged."));
-            QStringList autoCorrections;
-            autoCorrections.push_back("skg://view_open_similar_categories");
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title="skg://view_open_similar_categories";
+	      a.IsRecommended=false;
+	      autoCorrections.push_back(a);
+	    }	
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
