@@ -218,7 +218,7 @@ void SKGCategoriesPluginWidget::setState(const QString& iState)
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    // !!! Must be done here after setFilter
+    ui.kCategoriesView->setFilter(KIcon(root.attribute("title_icon")), root.attribute("title"), root.attribute("whereClause"));
     ui.kCategoriesView->setState(root.attribute("view"));
 }
 
