@@ -333,13 +333,57 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(4);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled operation '%1' not uptodate", name));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled operation '%1' does not have the amount of the last inserted operation (%2)", name, amountLastOperation));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Update the operation amount (%1)", amountLastOperation));
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Update the next scheduled operation amount (%1)", amountLastOperation);
+	      a.IconName="system-run";
+	      a.IsRecommended=true;
+	      autoCorrections.push_back(a);
+	    }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
     }
 
+    // Recurrent operation with the last inserted operation having a different date
+    if (!iIgnoredAdvice.contains("skgscheduledplugin_newdate")) {
+        SKGStringListList result;
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT r.id, r.d_date, "
+                "date(r2.d_date, '+'||((CASE r.t_period_unit WHEN 'W' THEN 7  ELSE 1 END)*r.i_period_increment)||' '||(CASE r.t_period_unit WHEN 'M' THEN 'month' WHEN 'Y' THEN 'year' ELSE 'day' END)) "
+                "FROM v_recurrentoperation_display r "
+                "INNER JOIN (SELECT MAX(d_date) as d_date, r_recurrentoperation_id FROM v_operation_display GROUP BY r_recurrentoperation_id) r2 "
+                "WHERE r2.r_recurrentoperation_id=r.id AND r.d_PREVIOUS!=r2.d_date", result);
+        int nb = result.count();
+        for (int i = 1; i < nb; ++i) {  // Ignore header
+            // Get parameters
+            QStringList line = result.at(i);
+            int idRecu = SKGServices::stringToInt(line.at(0));
+            QString currentDate = line.at(1);
+            QString newDate = line.at(2);
+            if (SKGServices::stringToTime(newDate).date() > QDate::currentDate() && SKGServices::stringToTime(newDate).date() != SKGServices::stringToTime(currentDate).date()) {
+                SKGRecurrentOperationObject recu(m_currentBankDocument, idRecu);
+                QString name = recu.getDisplayName();
+
+                SKGAdvice ad;
+                ad.setUUID("skgscheduledplugin_newdate|" % line.at(0) % ';' % newDate);
+                ad.setPriority(4);
+                ad.setShortMessage(i18nc("Advice on making the best (short)", "Scheduled operation '%1' not uptodate", name));
+                ad.setLongMessage(i18nc("Advice on making the best (long)", "The scheduled operation '%1' does not have the date aligned with the last inserted operation (%2)", name, currentDate));
+		QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+		{
+		  SKGAdvice::SKGAdviceAction a;
+		  a.Title=i18nc("Advice on making the best (action)", "Update the next scheduled operation date (%1)", newDate);
+		  a.IconName="system-run";
+		  a.IsRecommended=true;
+		  autoCorrections.push_back(a);
+		}
+                ad.setAutoCorrections(autoCorrections);
+                output.push_back(ad);
+            }
+        }
+    }
+
     // Possible recurrent operations
     if (!iIgnoredAdvice.contains("skgscheduledplugin_possibleschedule")) {
         SKGStringListList result;
@@ -362,8 +406,14 @@ SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
             ad.setPriority(4);
             ad.setShortMessage(i18nc("Advice on making the best (short)", "Possible schedule '%1'", name));
             ad.setLongMessage(i18nc("Advice on making the best (long)", "The operation '%1' seems to be regularly created and could be scheduled", name));
-            QStringList autoCorrections;
-            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Monthly schedule the operation '%1'", name));
+	    QList<SKGAdvice::SKGAdviceAction> autoCorrections;
+	    {
+	      SKGAdvice::SKGAdviceAction a;
+	      a.Title=i18nc("Advice on making the best (action)", "Monthly schedule the operation '%1'", name);
+	      a.IconName=icon();
+	      a.IsRecommended=true;
+	      autoCorrections.push_back(a);
+	    }
             ad.setAutoCorrections(autoCorrections);
             output.push_back(ad);
         }
@@ -412,6 +462,31 @@ SKGError SKGScheduledPlugin::executeAdviceCorrection(const QString& iAdviceIdent
         // Display error
         SKGMainPanel::displayErrorMessage(err);
 
+        return err;
+    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_newdate|"))) {
+        // Get parameters
+        QString parameters = iAdviceIdentifier.right(iAdviceIdentifier.length() - 27);
+        int pos = parameters.indexOf(';');
+        int id = SKGServices::stringToInt(parameters.left(pos));
+        QString newDate = parameters.right(parameters.length() - 1 - pos);
+
+        // Update the operation
+        {
+            SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Update scheduled operation"), err);
+            SKGRecurrentOperationObject rop(m_currentBankDocument, id);
+            IFOKDO(err, rop.setDate(SKGServices::stringToTime(newDate).date()))
+            IFOKDO(err, rop.save())
+        }
+
+        // status bar
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Scheduled operation updated.")))
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message", "Update failed"));
+        }
+
+        // Display error
+        SKGMainPanel::displayErrorMessage(err);
+
         return err;
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgscheduledplugin_possibleschedule|"))) {
         // Get parameters
