@@ -17,6 +17,7 @@
 /** @file
  * This file defines classes SKGRuleObject.
  *
+ *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgruleobject.h"
@@ -27,6 +28,7 @@
 
 #include "skgunitvalueobject.h"
 #include "skgoperationobject.h"
+#include "skgdocumentbank.h"
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
 
@@ -261,26 +263,12 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
         }
     } else if (getActionType() == SKGRuleObject::ALARM) {
         // Alarm mode
-        QString wc = getSelectSqlOrder();
-        if (wc.isEmpty()) {
-            wc = "1=1";
-        }
-
-        SKGDocument* doc = getDocument();
+        SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
         if (doc) {
-            QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, ALARM, false);
-            if (list.count()) {
-                QString sql = list.at(0);
-                sql.replace("#WC#", wc);
-
-                SKGStringListList result;
-                err = doc->executeSelectSqliteOrder(sql, result);
-                if (!err && result.count() == 2) {
-                    // Is alarm raised ?
-                    if (result.at(1).at(0) == "1") {
-                        doc->sendMessage(result.at(1).at(3));
-                    }
-                }
+            SKGRuleObject::SKGAlarmInfo alarm = getAlarmInfo();
+            if (!alarm.Message.isEmpty()) {
+                SKGServices::SKGUnitInfo unit = doc->getPrimaryUnit();
+                getDocument()->sendMessage(alarm.Message.arg(doc->formatMoney(alarm.Amount, unit, false)).arg(doc->formatMoney(alarm.Limit, unit, false)).arg(doc->formatMoney(alarm.Amount - alarm.Limit, unit, false)));
             }
         }
     } else if (getActionType() == SKGRuleObject::APPLYTEMPLATE) {
