@@ -152,7 +152,8 @@ public:
     static bool m_currentActionCanceled;
     static SKGMainPanel* m_mainPanel;
 
-    static int progressBarCallBack(int iPos, qint64 iTime, const QString& iName, void* iProgressBar) {
+    static int progressBarCallBack(int iPos, qint64 iTime, const QString& iName, void* iProgressBar)
+    {
         Q_UNUSED(iTime);
         QProgressBar* progressBar = NULL;
         QPushButton* button = NULL;
@@ -195,18 +196,21 @@ public:
         return (SKGMainPanelPrivate::m_currentActionCanceled ? 1 : 0);
     }
 
-    static bool naturalLessThan(const QString& s1, const QString& s2) {
+    static bool naturalLessThan(const QString& s1, const QString& s2)
+    {
         return (KStringHandler::naturalCompare(s1, s2, Qt::CaseInsensitive) < 0);
     }
 
-    static bool adviceLessThan(const SKGAdvice& s1, const SKGAdvice& s2) {
+    static bool adviceLessThan(const SKGAdvice& s1, const SKGAdvice& s2)
+    {
         if (s1.getPriority() == s2.getPriority()) {
             return (s1.getShortMessage() > s2.getShortMessage());
         }
         return (s1.getPriority() > s2.getPriority());
     }
 
-    static void setAttribute(QDomElement& iRoot, const QString& iPath, const QString& iValue) {
+    static void setAttribute(QDomElement& iRoot, const QString& iPath, const QString& iValue)
+    {
         int pos = iPath.indexOf('.');
         if (pos == -1) {
             iRoot.setAttribute(iPath, iValue);
@@ -227,11 +231,13 @@ public:
         }
     }
 
-    static bool iconInSystemtray() {
+    static bool iconInSystemtray()
+    {
         return skgbasegui_settings::icon_in_system_tray();
     }
 
-    void refreshTabPosition() {
+    void refreshTabPosition()
+    {
         m_tabWidget->setTabPosition(static_cast<KTabWidget::TabPosition>(skgbasegui_settings::main_tabs_position()));
     }
 };
@@ -449,6 +455,16 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     connect(panelAction, SIGNAL(triggered()), toggle, SLOT(trigger()));
     connect(toggle, SIGNAL(toggled(bool)), panelAction, SLOT(setChecked(bool)));
 
+    QAction* toggle2 = d->ui.kDockMessages->toggleViewAction();
+    KAction* panelAction2 = actionCollection()->addAction("view_messages");
+    registerGlobalAction("view_messages", panelAction2);
+    panelAction2->setCheckable(true);
+    panelAction2->setChecked(toggle2->isChecked());
+    panelAction2->setText(toggle2->text());
+    panelAction2->setShortcut(Qt::SHIFT + Qt::Key_F8);
+    connect(panelAction2, SIGNAL(triggered()), toggle2, SLOT(trigger()));
+    connect(toggle2, SIGNAL(toggled(bool)), panelAction2, SLOT(setChecked(bool)));
+
     KSelectAction* contextMenu = new KSelectAction(KIcon("tab-new"), i18nc("Noun", "Pages"), this);
     registerGlobalAction("view_contextmenu" , contextMenu);
 
@@ -594,6 +610,10 @@ SKGMainPanel::SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument,
     kCancelButton->setVisible(false);
     connect(kCancelButton, SIGNAL(clicked()), this, SLOT(onCancelCurrentAction()));
 
+    //
+    d->ui.kClearMessageBtn->setIcon(KIcon("edit-clear"));
+    connect(d->ui.kClearMessageBtn, SIGNAL(clicked(bool)), this, SLOT(onClearMessages()));
+
     // Add special button in toolbar
     KToolBar* tb = toolBar();
     if (tb) {
@@ -2182,19 +2202,28 @@ KMessageWidget* SKGMainPanel::displayMessage(const QString& iMessage, SKGDocumen
         msg->setMessageType(static_cast<KMessageWidget::MessageType>(iType));
         QTimer::singleShot(iType == SKGDocument::Positive ? 5000 : iType == SKGDocument::Information ? 10000 : 20000, msg, SLOT(deleteLater()));
         d->m_mainLayout->insertWidget(qMax(d->m_mainLayout->indexOf(d->m_mainWidget) - 1, 0), msg);
-    }
 
-    // Emit message
-    //  [Event/error]
-    //  [Event/neutral]
-    //  [Event/positive]
-    KNotification* notification = new KNotification(iType == SKGDocument::Error ? "error" : (iType == SKGDocument::Positive ? "positive" : "neutral") , this);
-    notification->setText(iMessage);
-    notification->sendEvent();
+        // Store message
+        KMessageWidget* msg2 = new KMessageWidget(this);
+        msg2->setText(iMessage);
+        msg2->setMessageType(static_cast<KMessageWidget::MessageType>(iType));
+        QVBoxLayout* l = qobject_cast< QVBoxLayout* >(d->ui.kMessagesLayout->layout());
+        if (l) {
+            l->insertWidget(0, msg2);
+        }
 
-    // Alert
-    if (iType == SKGDocument::Error || iType == SKGDocument::Warning) {
-        qApp->alert(this);
+        // Emit message
+        //  [Event/error]
+        //  [Event/neutral]
+        //  [Event/positive]
+        KNotification* notification = new KNotification(iType == SKGDocument::Error ? "error" : (iType == SKGDocument::Positive ? "positive" : "neutral") , this);
+        notification->setText(iMessage);
+        notification->sendEvent();
+
+        // Alert
+        if (iType == SKGDocument::Error || iType == SKGDocument::Warning) {
+            qApp->alert(this);
+        }
     }
 
     return msg;
@@ -2381,4 +2410,20 @@ SKGTabWidget* SKGMainPanel::getTabWidget() const
     return d->m_tabWidget;
 }
 
+void SKGMainPanel::onClearMessages()
+{
+    QLayout* l = d->ui.kMessagesLayout->layout();
+    if (l) {
+        // Remove all item of the layout
+        while (l->count() > 1) {
+            QLayoutItem* child = l->takeAt(0);
+            if (child) {
+                QWidget* w = child->widget();
+                delete w;
+                delete child;
+            }
+        }
+    }
+}
+
 #include "skgmainpanel.moc"
