@@ -36,7 +36,9 @@ SKGTabWidgetDesignerPlugin::SKGTabWidgetDesignerPlugin(QObject* iParent)
 void SKGTabWidgetDesignerPlugin::initialize(QDesignerFormEditorInterface*  iCore)
 {
     Q_UNUSED(iCore);
-    if (m_initialized) return;
+    if (m_initialized) {
+        return;
+    }
 
     m_initialized = true;
 }
